@@ -17,7 +17,10 @@ def _extract_bounding_boxes(tree, bounds):
 
         # If the split's new right threshold (so the node on the left) is more specific
         # than the previous one, update the bound and recurse
-        if tree["split_condition"] < bounds[tree["split"]][1]:
+        if (
+            tree["split_condition"] < bounds[tree["split"]][1]
+            and tree["split_condition"] > bounds[tree["split"]][0]
+        ):
             old_bound = bounds[tree["split"]][1]
             bounds[tree["split"]][1] = tree["split_condition"]
 
@@ -29,7 +32,10 @@ def _extract_bounding_boxes(tree, bounds):
 
         # If the split's new left threshold (so the node on the right) is more specific
         # than the previous one, update the bound and recurse
-        if tree["split_condition"] > bounds[tree["split"]][0]:
+        if (
+            tree["split_condition"] > bounds[tree["split"]][0]
+            and tree["split_condition"] < bounds[tree["split"]][1]
+        ):
             old_bound = bounds[tree["split"]][0]
             bounds[tree["split"]][0] = tree["split_condition"]
 
