@@ -4,8 +4,10 @@ import time
 try:
     from gurobipy import *
 except:
-    raise ImportError("""The python GUROBI package could not be imported. 
-    To install it, run: python -m pip install -i https://pypi.gurobi.com gurobipy""")
+    raise ImportError(
+        """The python GUROBI package could not be imported. 
+    To install it, run: python -m pip install -i https://pypi.gurobi.com gurobipy"""
+    )
 
 from tqdm import tqdm
 
